@@ -26,6 +26,10 @@ tidygraph::.E
 #' @export
 tidygraph::mutate
 
+#' @importFrom tidygraph rename
+#' @export
+tidygraph::rename
+
 #' @importFrom tidygraph filter
 #' @export
 tidygraph::filter
@@ -34,6 +38,10 @@ tidygraph::filter
 #' @export
 tidygraph::activate
 
+#' @importFrom tidygraph bind_edges
+#' @export
+tidygraph::bind_edges
+
 expect_nodes <- function() {
   if (!.graph_context$free() && .graph_context$active() != "nodes") {
     stop("This call requires nodes to be active", call. = FALSE)
